@@ -14,13 +14,12 @@
 ##' @family particle filter methods
 ##' @family elementary algorithms
 ##' @inheritSection pomp Note for Windows users
-##' 
+##' @inheritParams pfilter
 ##' @inheritParams pomp
 ##' @param Np integer; the number of particles to use, i.e., the size of the ensemble.
 ##' 
 ##' @return
 ##' An object of class \sQuote{kalmand_pomp}.
-##'
 ##' @references
 ##'
 ##' \Evensen1994
@@ -107,7 +106,7 @@ setMethod(
         ...,
         verbose=verbose
       ),
-      error = function (e) pStop("enkf",conditionMessage(e))
+      error = function (e) pStop(who="enkf",conditionMessage(e))
     )
 
   }
@@ -128,7 +127,7 @@ setMethod(
         ...,
         verbose=verbose
       ),
-      error = function (e) pStop("enkf",conditionMessage(e))
+      error = function (e) pStop(who="enkf",conditionMessage(e))
     )
 
   }
@@ -149,7 +148,7 @@ setMethod(
         ...,
         verbose=verbose
       ),
-      error = function (e) pStop("enkf",conditionMessage(e))
+      error = function (e) pStop(who="enkf",conditionMessage(e))
     )
 
   }
@@ -324,7 +323,7 @@ setMethod(
         ...,
         verbose=verbose
       ),
-      error = function (e) pStop("eakf",conditionMessage(e))
+      error = function (e) pStop(who="eakf",conditionMessage(e))
     )
 
   }
@@ -345,7 +344,7 @@ setMethod(
         ...,
         verbose=verbose
       ),
-      error = function (e) pStop("eakf",conditionMessage(e))
+      error = function (e) pStop(who="eakf",conditionMessage(e))
     )
 
   }
