@@ -117,7 +117,7 @@ setMethod(
       plot_spect_internal(x,max.plots.per.page=max.plots.per.page,
         plot.data=plot.data,quantiles=quantiles,quantile.styles=quantile.styles,
         data.styles=data.styles),
-      error = function (e) pStop("plot",conditionMessage(e))
+      error = function (e) pStop(who="plot",conditionMessage(e))
     )
 
   }
@@ -256,7 +256,7 @@ abc_diagnostics <- function (z, pars, scatter = FALSE, ...) {
     x <- lapply(seq_along(x),\(n)cbind(x[[n]],.num=n))
     x <- do.call(rbind,x)
     if (ncol(x)<3) {
-      pStop("plot","can't make a scatterplot with only one variable.")
+      pStop(who="plot","can't make a scatterplot with only one variable.")
     } else {
       pairs(x[,pars],col=x[,".num"],...)
     }
@@ -460,7 +460,7 @@ plot_spect_internal <- function (x, max.plots.per.page, plot.data,
     if (length(quantile.styles[[i]])==1)
       quantile.styles[[i]] <- rep(quantile.styles[[i]],nquants)
     if (length(quantile.styles[[i]])<nquants) {
-      pWarn("plot",sQuote("quantile.styles"),
+      pWarn(who="plot",sQuote("quantile.styles"),
         " contains an element with more than 1 entry but ",
         "fewer entries than quantiles.")
       quantile.styles[[i]]<-rep(quantile.styles[[i]],nquants)
@@ -479,7 +479,7 @@ plot_spect_internal <- function (x, max.plots.per.page, plot.data,
       if(length(data.styles[[i]])==1)
         data.styles[[i]] <- rep(data.styles[[i]],nreps)
       if(length(data.styles[[i]]) < nreps) {
-        pWarn("plot",sQuote("data.styles"),
+        pWarn(who="plot",sQuote("data.styles"),
           " contains an element with more than 1 entry but ",
           "fewer entries than observed variables.")
         data.styles[[i]] <- rep(data.styles[[i]],nreps)
