@@ -4,6 +4,8 @@
 ##' They are low-level functions that do the work needed by the package's inference methods.
 ##'
 ##' They include \describe{
+##' \item{\code{\link{rinit}}}{which samples from the initial-state distribution,}
+##' \item{\code{\link{dinit}}}{which evaluates the initial-state density,}
 ##' \item{\code{\link{dmeasure}}}{which evaluates the measurement model density,}
 ##' \item{\code{\link{rmeasure}}}{which samples from the measurement model distribution,}
 ##' \item{\code{\link{emeasure}}}{which computes the expectation of the observed variables conditional on the latent state,}
@@ -23,52 +25,41 @@
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso \link[=basic components]{basic model components},
-##' \link[=elementary algorithms]{elementary algorithms},
-##' \link[=estimation algorithms]{estimation algorithms}
-##'
+##' @seealso \link[=basic_components]{basic model components},
+##' \link[=elementary_algorithms]{elementary algorithms},
+##' \link[=estimation_algorithms]{estimation algorithms}
 ##' @author Aaron A. King
-##'
 ##' @concept extending the pomp package
 ##' @concept low-level interface
 NULL
 
-##' dmeasure
+##' dmeasure workhorse
 ##'
 ##' \code{dmeasure} evaluates the probability density of observations given states.
-##'
 ##' @name dmeasure
 ##' @docType methods
 ##' @aliases dmeasure,ANY-method dmeasure,missing-method
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the measurement density evaluator: \link{dmeasure specification}
-##'
+##' @seealso Specification of the measurement density evaluator: \link{dmeasure_spec}
 ##' @param object an object of class \sQuote{pomp}, or of a class that extends \sQuote{pomp}.
 ##' This will typically be the output of \code{pomp}, \code{simulate}, or one of the \pkg{pomp} inference algorithms.
-##'
 ##' @param x an array containing states of the unobserved process.
 ##' The dimensions of \code{x} are \code{nvars} x \code{nrep} x \code{ntimes},
 ##' where \code{nvars} is the number of state variables,
 ##' \code{nrep} is the number of replicates,
 ##' and \code{ntimes} is the length of \code{times}.
 ##' One can also pass \code{x} as a named numeric vector, which is equivalent to the \code{nrep=1}, \code{ntimes=1} case.
-##'
 ##' @param y a matrix containing observations.
 ##' The dimensions of \code{y} are \code{nobs} x \code{ntimes}, where \code{nobs} is the number of observables
 ##' and \code{ntimes} is the length of \code{times}.
-##'
 ##' @param times a numeric vector (length \code{ntimes}) containing times.
 ##' These must be in non-decreasing order.
-##'
 ##' @param params a \code{npar} x \code{nrep} matrix of parameters.
 ##' Each column is treated as an independent parameter set, in correspondence with the corresponding column of \code{x}.
-##'
 ##' @param log if TRUE, log probabilities are returned.
-##'
 ##' @param \dots additional arguments are ignored.
-##'
 ##' @return
 ##' \code{dmeasure} returns a matrix of dimensions \code{nreps} x \code{ntimes}.
 ##' If \code{d} is the returned matrix, \code{d[j,k]} is the likelihood (or log likelihood if \code{log = TRUE}) of the observation \code{y[,k]} at time \code{times[k]} given the state \code{x[,j,k]}.
@@ -129,7 +120,7 @@ dmeasure_internal <- function (object, y, x, times, params, ..., log = FALSE,
   .Call(P_do_dmeasure,object,y,x,times,params,log,.gnsi)  
 }
 
-##' dprior
+##' dprior workhorse
 ##'
 ##' Evaluates the prior probability density.
 ##'
@@ -140,10 +131,8 @@ dmeasure_internal <- function (object, y, x, times, params, ..., log = FALSE,
 ##' @family Bayesian methods
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the prior density evaluator: \link{prior specification}
-##'
+##' @seealso Specification of the prior density evaluator: \link{prior_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' The required density (or log density), as a numeric vector.
 ##'
@@ -197,7 +186,7 @@ dprior_internal <- function (object, params, log = FALSE,
   .Call(P_do_dprior,object,params,log,.gnsi)
 }
 
-##' dprocess
+##' dprocess workhorse
 ##'
 ##' Evaluates the probability density of a sequence of consecutive state transitions.
 ##'
@@ -207,10 +196,8 @@ dprior_internal <- function (object, params, log = FALSE,
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the process-model density evaluator: \link{dprocess specification}
-##'
+##' @seealso Specification of the process-model density evaluator: \link{dprocess_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' \code{dprocess} returns a matrix of dimensions \code{nrep} x \code{ntimes-1}.
 ##' If \code{d} is the returned matrix, \code{d[j,k]} is the likelihood (or the log likelihood if \code{log=TRUE}) of the transition from state \code{x[,j,k-1]} at time \code{times[k-1]} to state \code{x[,j,k]} at time \code{times[k]}.
@@ -267,7 +254,7 @@ dprocess_internal <- function (object, x, times, params, log = FALSE, .gnsi = TR
   .Call(P_do_dprocess,object,x,times,params,log,.gnsi)
 }
 
-##' partrans
+##' partrans workhorse
 ##'
 ##' Performs parameter transformations.
 ##'
@@ -278,10 +265,8 @@ dprocess_internal <- function (object, x, times, params, log = FALSE, .gnsi = TR
 ##' @concept extending the pomp package
 ##' @concept low-level interface
 ##' @seealso Specification of parameter transformations: \code{\link{parameter_trans}}
-##'
 ##' @inheritParams dmeasure
 ##' @param dir the direction of the transformation to perform.
-##'
 ##' @return
 ##' If \code{dir=fromEst}, the parameters in \code{params} are assumed to be on the estimation scale and are transformed onto the natural scale.
 ##' If \code{dir=toEst}, they are transformed onto the estimation scale.
@@ -340,7 +325,7 @@ partrans_internal <- function (object, params, dir = c("fromEst", "toEst"),
   params
 }
 
-##' rinit
+##' rinit workhorse
 ##'
 ##' Samples from the initial-state distribution.
 ##'
@@ -350,12 +335,10 @@ partrans_internal <- function (object, params, dir = c("fromEst", "toEst"),
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the initial-state distribution: \link{rinit specification}
-##'
+##' @seealso_spec of the initial-state distribution: \link{rinit_spec}
 ##' @inheritParams dmeasure
 ##' @param t0 the initial time, i.e., the time corresponding to the initial-state distribution.
 ##' @param nsim optional integer; the number of initial states to simulate per column of \code{params}.
-##'
 ##' @return
 ##' \code{rinit} returns an \code{nvar} x \code{nsim*ncol(params)} matrix of state-process initial conditions when given an \code{npar} x \code{nsim} matrix of parameters, \code{params}, and an initial time \code{t0}.
 ##' By default, \code{t0} is the initial time defined when the \sQuote{pomp} object ws constructed.
@@ -411,7 +394,76 @@ rinit_internal <- function (object, params, t0, nsim = 1,
   .Call(P_do_rinit,object,params,t0,nsim,.gnsi)
 }
 
-##' rmeasure
+##' dinit workhorse
+##'
+##' Evaluates the initial-state density.
+##'
+##' @name dinit
+##' @docType methods
+##' @aliases dinit,ANY-method dinit,missing-method
+##' @family pomp workhorses
+##' @concept extending the pomp package
+##' @concept low-level interface
+##' @seealso Specification of the initial-state distribution: \link{dinit_spec}
+##' @inheritParams dmeasure
+##' @param t0 the initial time, i.e., the time corresponding to the initial-state distribution.
+##' @return
+##' \code{dinit} returns a 1-D numerical array containing the likelihoods (or log likelihoods if \code{log=TRUE}).
+##' By default, \code{t0} is the initial time defined when the \sQuote{pomp} object ws constructed.
+##'
+NULL
+
+setGeneric(
+  "dinit",
+  function (object, ...)
+    standardGeneric("dinit")
+)
+
+setMethod(
+  "dinit",
+  signature=signature(object="missing"),
+  definition=function (...) {
+    reqd_arg("dinit","object")
+  }
+)
+
+setMethod(
+  "dinit",
+  signature=signature(object="ANY"),
+  definition=function (object, ...) {
+    undef_method("dinit",object)
+  }
+)
+
+##' @export
+##' @rdname dinit
+setMethod(
+  "dinit",
+  signature=signature("pomp"),
+  definition=function (
+    object,
+    params = coef(object),
+    t0 = timezero(object),
+    x,
+    log = FALSE,
+    ...
+  ) {
+    tryCatch(
+      dinit_internal(object=object,x=x,params=params,t0=t0,log=log,...),
+      error = function (e) pStop(who="dinit",conditionMessage(e))
+    )
+  }
+)
+
+dinit_internal <- function (object, x, params, t0, log, .gnsi = TRUE, ...) {
+  storage.mode(x) <- "double"
+  storage.mode(params) <- "double"
+  pompLoad(object)
+  on.exit(pompUnload(object))
+  .Call(P_do_dinit,object,t0,x,params,log,.gnsi)
+}
+
+##' rmeasure workhorse
 ##'
 ##' Sample from the measurement model distribution, given values of the latent states and the parameters.
 ##'
@@ -421,10 +473,8 @@ rinit_internal <- function (object, params, t0, nsim = 1,
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the measurement-model simulator: \link{rmeasure specification}
-##'
+##' @seealso Specification of the measurement-model simulator: \link{rmeasure_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' \code{rmeasure} returns a rank-3 array of dimensions
 ##' \code{nobs} x \code{nrep} x \code{ntimes},
@@ -482,7 +532,7 @@ rmeasure_internal <- function (object, x, times, params,
   .Call(P_do_rmeasure,object,x,times,params,.gnsi)
 }
 
-##' emeasure
+##' emeasure workhorse
 ##'
 ##' Return the expected value of the observed variables, given values of the latent states and the parameters.
 ##'
@@ -490,10 +540,8 @@ rmeasure_internal <- function (object, x, times, params,
 ##' @docType methods
 ##' @aliases emeasure,ANY-method emeasure,missing-method
 ##' @family pomp workhorses
-##' @seealso Specification of the measurement-model expectation: \link{emeasure specification}
-##'
+##' @seealso Specification of the measurement-model expectation: \link{emeasure_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' \code{emeasure} returns a rank-3 array of dimensions
 ##' \code{nobs} x \code{nrep} x \code{ntimes},
@@ -551,7 +599,7 @@ emeasure_internal <- function (object, x, times, params,
   .Call(P_do_emeasure,object,x,times,params,.gnsi)
 }
 
-##' vmeasure
+##' vmeasure workhorse
 ##'
 ##' Return the covariance matrix of the observed variables, given values of the latent states and the parameters.
 ##'
@@ -559,10 +607,8 @@ emeasure_internal <- function (object, x, times, params,
 ##' @docType methods
 ##' @aliases vmeasure,ANY-method vmeasure,missing-method
 ##' @family pomp workhorses
-##' @seealso Specification of the measurement-model covariance matrix: \link{vmeasure specification}
-##'
+##' @seealso Specification of the measurement-model covariance matrix: \link{vmeasure_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' \code{vmeasure} returns a rank-4 array of dimensions
 ##' \code{nobs} x \code{nobs} x \code{nrep} x \code{ntimes},
@@ -622,7 +668,7 @@ vmeasure_internal <- function (object, x, times, params,
   .Call(P_do_vmeasure,object,x,times,params,.gnsi)
 }
 
-##' rprior
+##' rprior workhorse
 ##'
 ##' Sample from the prior probability distribution.
 ##'
@@ -633,10 +679,8 @@ vmeasure_internal <- function (object, x, times, params,
 ##' @family Bayesian methods
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the prior distribution simulator: \link{prior specification}
-##'
+##' @seealso Specification of the prior distribution simulator: \link{prior_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' A numeric matrix containing the required samples.
 ##'
@@ -687,7 +731,7 @@ rprior_internal <- function (object, params, .gnsi = TRUE, ...) {
   .Call(P_do_rprior,object,params,.gnsi)
 }
 
-##' rprocess
+##' rprocess workhorse
 ##'
 ##' \code{rprocess} simulates the process-model portion of partially-observed Markov process.
 ##'
@@ -700,21 +744,16 @@ rprior_internal <- function (object, params, .gnsi = TRUE, ...) {
 ##' @family pomp workhorses
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the process-model simulator: \link{rprocess specification}
-##'
+##' @seealso Specification of the process-model simulator: \link{rprocess_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @param x0 an \code{nvar} x \code{nrep} matrix containing the starting state of the system.
 ##' Columns of \code{x0} correspond to states;
 ##' rows to components of the state vector.
 ##' One independent simulation will be performed for each column.
 ##' Note that in this case, \code{params} must also have \code{nrep} columns.
-##'
 ##' @param t0 the initial time, i.e., the time corresponding to the state in \code{x0}.
-##'
 ##' @param params a \code{npar} x \code{nrep} matrix of parameters.
 ##' Each column is treated as an independent parameter set, in correspondence with the corresponding column of \code{x0}.
-##'
 ##' @return
 ##' \code{rprocess} returns a rank-3 array with rownames.
 ##' Suppose \code{x} is the array returned.
@@ -778,13 +817,13 @@ rprocess_internal <- function (object, x0, t0, times, params, ...,
   .Call(P_do_rprocess,object,x0,t0,times,params,.gnsi)
 }
 
-##' skeleton
+##' skeleton workhorse
 ##'
 ##' Evaluates the deterministic skeleton at a point or points in state space, given parameters.
 ##' In the case of a discrete-time system, the skeleton is a map.
 ##' In the case of a continuous-time system, the skeleton is a vectorfield.
 ##' NB: \code{skeleton} just evaluates the deterministic skeleton;
-##' it does not iterate or integrate (see \code{\link{trajectory}} for this).
+##' it does not iterate or integrate (see \code{\link{flow}} and \code{\link{trajectory}} for this).
 ##'
 ##' @name skeleton
 ##' @docType methods
@@ -793,10 +832,8 @@ rprocess_internal <- function (object, x0, t0, times, params, ...,
 ##' @family deterministic methods
 ##' @concept extending the pomp package
 ##' @concept low-level interface
-##' @seealso Specification of the deterministic skeleton: \link{skeleton specification}
-##'
+##' @seealso Specification of the deterministic skeleton: \link{skeleton_spec}
 ##' @inheritParams dmeasure
-##'
 ##' @return
 ##' \code{skeleton} returns an array of dimensions \code{nvar} x \code{nrep} x \code{ntimes}.
 ##' If \code{f} is the returned matrix, \code{f[i,j,k]} is the i-th component of the deterministic skeleton at time \code{times[k]} given the state \code{x[,j,k]} and parameters \code{params[,j]}.
